#!/usr/bin/gnuplot

# Flock et al. (2016) alpha viscosity.

au = 1.496e11  # m
G = 6.67e-11  # SI
k = 1.38e-23  # SI
m_u = 1.66e-27  # kg
sigma = 5.67e-8  # SI
cm =  1.e-2

M_star = 1.99e30
L_star = 3.84e26  # W
alpha_in = 1.9e-2
alpha_out = 1e-3
Delta_T = 25.  # K
gamma = 1.4
A = 0.1
mu = 1.0
T_MRI = 1000.

# this is ONLY radiative profile!
T(r) = ((1-A)*L_star/(16.*pi*sigma*r**2))**0.25
T(r) = 500.*(r/au)**(-0.5)

c_s(r) = sqrt(gamma*k*T(r)/(mu*m_u))
Omega(r) = sqrt(G*M_star/r**3)
alpha(r) = (alpha_in - alpha_out)*(1-tanh((T_MRI-T(r))/Delta_T))/2. + alpha_out
nu(r) = alpha(r)*c_s(r)**2/Omega(r)

GM_SI = 1.32712440018e20
AU_SI = 149597870700.0
R_STANDARD = 8.3144598
MMW = 2.4
R_SI = R_STANDARD/(MMW*0.001)
T2SI = GM_SI/R_SI/AU_SI

load "test_relax/config.plt"
f(i) = Rmin+(Rmax-Rmin)*i/Nsec/Nr
g(T) = T*T2SI

########################################################################

set term x11

set xl "r [au]"
set yl "T [K]"

set xr [0.01:10.0]
set yr [0:2000]

set samples 1000
set logscale x
set key left

tmp=0.20; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
tmp=5.20; set arrow from tmp,graph 0 to tmp,graph 1

p T(x*au),\
  "test_relax/gastemper0030.cfg" u (f($0)):(g($1)) w l,\
  T_MRI w l lt 0
pa -1

########################################################################

set xl "r [au]"
set yl "nu [m^2 s^-1]"

set xr [0.01:10.0]
set autoscale y

p nu(x*au),\
  5.e14 * (cm**2),\
  3.*5.e13 * (cm**2)
pa -1


