#!/usr/bin/gnuplot

G = 6.67e-11
M_S = 1.989e30
M_E = 5.972e24
au = 1.496e11
yr = 365.25*86400.0
cm = 1.e-2
g = 1.e-3

dt = 0.314159
P = 20*dt

f(t) = t/P
g(m) = m*M_S/M_E
h(m)=sqrt(g(m))*3.0

n(r) = sqrt(G*M_S/r**3)
dadt(r,m,Gamma_cgs) = 2*Gamma_cgs*g*cm**2/(r*au*n(r*au)*m*M_S) / (au/yr)

r = 1*au
print "r = ", r, " m"
print "n = ", n(r), " rad s^-1 = ", n(r)*yr, " rad yr^-1"

FACTOR=0.0

########################################################################

set colors classic
set term x11

set xl "r [au]"
set yl "da/dt [au/yr]"

tmp=1.e-5
set yr [-tmp:tmp]
set zeroaxis
set key left bottom

set style line 1 lt 1
set style line 2 lt 9
set style line 3 lt 3
set style line 4 lt 5
set style line 5 lt 2

p \
  "Mercury.out"  u 1:(dadt($1,$2,$7)) t "Paardekooper etal. (2011)" w l lc 1,\
  "Venus.out"    u 1:(dadt($1,$2,$7)) not w l lc 2,\
  "0.5Earth.out" u 1:(dadt($1,$2,$7)) not w l lc 3,\
  "Mars.out"     u 1:(dadt($1,$2,$7)) not w l lc 5,\
  "../out_META/5/dadt.out" u 2:($3):1 not w l lc 'gray' lw 3,\
  "../out_META/5/dadt.out" u 2:($3):1 t "5planet inverse A2.0 NOHEATING" w p lc var lw 3 ps 2 pt 6,\

pa -1

set term png small
set out "dadt.png"
rep

q

  "../out_META/5/dadt.out" u 2:($3-FACTOR*abs($3)):1 w lp lw 3 ps 2 dt 2



